aboutsummaryrefslogtreecommitdiffstats
path: root/src/filter/FilterPlugin.hxx
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--src/filter/FilterPlugin.hxx14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/filter/FilterPlugin.hxx b/src/filter/FilterPlugin.hxx
index 443d29881..68ad74240 100644
--- a/src/filter/FilterPlugin.hxx
+++ b/src/filter/FilterPlugin.hxx
@@ -1,5 +1,5 @@
/*
- * Copyright (C) 2003-2014 The Music Player Daemon Project
+ * Copyright (C) 2003-2015 The Music Player Daemon Project
* http://www.musicpd.org
*
* This program is free software; you can redistribute it and/or modify
@@ -26,7 +26,7 @@
#ifndef MPD_FILTER_PLUGIN_HXX
#define MPD_FILTER_PLUGIN_HXX
-struct config_param;
+struct ConfigBlock;
class Filter;
class Error;
@@ -36,32 +36,32 @@ struct filter_plugin {
/**
* Allocates and configures a filter.
*/
- Filter *(*init)(const config_param &param, Error &error);
+ Filter *(*init)(const ConfigBlock &block, Error &error);
};
/**
* Creates a new instance of the specified filter plugin.
*
* @param plugin the filter plugin
* @param param optional configuration section
* @param error location to store the error occurring, or nullptr to
* ignore errors.
* @return a new filter object, or nullptr on error
*/
Filter *
filter_new(const struct filter_plugin *plugin,
- const config_param &param, Error &error);
+ const ConfigBlock &block, Error &error);
/**
* Creates a new filter, loads configuration and the plugin name from
* the specified configuration section.
*
* @param param the configuration section
* @param error location to store the error occurring, or nullptr to
* ignore errors.
* @return a new filter object, or nullptr on error
*/
Filter *
-filter_configured_new(const config_param &param, Error &error);
+filter_configured_new(const ConfigBlock &block, Error &error);
#endif
@@ -36,32 +36,32 @@ struct filter_plugin {
*
* @param plugin the filter plugin
- * @param param optional configuration section
+ * @param block configuration section
* @param error location to store the error occurring, or nullptr to
* ignore errors.
@@ -36,32 +36,32 @@ struct filter_plugin {
* the specified configuration section.
*
- * @param param the configuration section
+ * @param block the configuration section
* @param error location to store the error occurring, or nullptr to
* ignore errors.